@@ -27,19 +27,19 @@ class Project(DeeplabelBase):
     owner: _ProjectOwner
 
     @classmethod
-    def _from_search_params(
+    def from_search_params(
         cls, params: Dict[str, Any], client: "deeplabel.client.BaseClient"
     ) -> List["Project"]:
         resp = client.get(client.label_url+ "/projects", params)
         projects = resp.json()["data"]["projects"]
         projects = [cls(**project, client=client) for project in projects]
-        return projects
+        return projects #type: ignore
 
     @classmethod
     def from_project_id(
         cls, project_id: str, client: "deeplabel.client.BaseClient"
     ) -> "Project":
-        projects = cls._from_search_params({"projectId": project_id}, client)
+        projects = cls.from_search_params({"projectId": project_id}, client)
         if not projects:
             raise InvalidIdError(f"No Project found with projectId: {project_id}")
         return projects[0]
@@ -49,6 +49,7 @@ class Project(DeeplabelBase):
         return deeplabel.label.folders.RootFolder(
             project_id=self.project_id,
             type=deeplabel.label.folders.FolderType.GALLERY,
+            folder_id=None,
             client=self.client
         )
 
@@ -57,6 +58,7 @@ class Project(DeeplabelBase):
         return deeplabel.label.folders.RootFolder(
             project_id=self.project_id,
             type=deeplabel.label.folders.FolderType.VIDEO,
+            folder_id=None,
             client=self.client
         )
     
